@@ -7,16 +7,28 @@
 
 #ifndef CONCONPIWIFUN_H_
 #define CONCONPIWIFUN_H_
-#include <iostream>
-#include <math.h>
-#include <limits>
-#include <Rcpp.h>
-#include <vector>
-#include <map>
+
 #include <assert.h>
 
-using namespace std;
+#include <Rcpp.h>
+//#include <utility>
+//#include <map>
+//#include <vector>
+//#include <limits>
+//#include <iostream>
 using namespace Rcpp;
+
+using std::pair;
+using std::map;
+using std::vector;
+//using std::numeric_limits;
+//#include <iostream>
+//#include <math.h>
+//#include <limits>
+
+//#include <vector>
+//#include <map>
+
 class cplfunction ;
 class cplfunctionvec;
 class cpqfunction ;
@@ -27,11 +39,12 @@ RCPP_EXPOSED_CLASS(cplfunctionvec)
 RCPP_EXPOSED_CLASS(cpqfunction)
 RCPP_EXPOSED_CLASS(cpqfunctionvec)
 
+
 bool isincreasing(Rcpp::NumericVector arg);
-double getSlope(pair<double,double> Coefficients,double val);
-double getVal(pair<double,double> Coefficients,double val);
-double getXetoile(pair<double,double> Coefficients);
-pair<double,double> Slopes2Coeffs(double Slopes0,double Slopes1);
+double getSlope(std::pair<double,double> Coefficients,double val);
+double getVal(std::pair<double,double> Coefficients,double val);
+double getXetoile(std::pair<double,double> Coefficients);
+std::pair<double,double> Slopes2Coeffs(double Slopes0,double Slopes1);
 
 #include "convex_functions_tools.hpp"
 
@@ -41,7 +54,6 @@ pair<double,double> Slopes2Coeffs(double Slopes0,double Slopes1);
 
 #include "cplfunctionvec.hpp"
 #include "cpqfunctionvec.hpp"
-
 //cplfunction InfConfFunct(cplfunction const & cplFunction1,cplfunction const & cplFunction2,double y );
 //cplfunction Sum(cplfunction const & cplfunction1,cplfunction const & cplfunction2);
 //cpqfunction Sumq(cpqfunction const & cpqfunction1,cpqfunction const & cpqfunction2);
